aboutsummaryrefslogtreecommitdiff
path: root/tests/test-live-actions.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test-live-actions.cpp')
-rw-r--r--tests/test-live-actions.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/test-live-actions.cpp b/tests/test-live-actions.cpp
index 562b358..eab8596 100644
--- a/tests/test-live-actions.cpp
+++ b/tests/test-live-actions.cpp
@@ -356,11 +356,11 @@ TEST_F(LiveActionsFixture, CalendarState)
a2.begin = next_begin;
a2.end = next_end;
- m_state->planner->thisMonth.set(std::vector<Appointment>({a1, a2}));
+ m_state->planner->this_month.set(std::vector<Appointment>({a1, a2}));
///
/// Now test the calendar state again.
/// The thisMonth field should now contain the appointments we just added.
///
calendar_state = g_action_group_get_action_state (action_group, "calendar");
@@ -356,11 +356,11 @@ TEST_F(LiveActionsFixture, CalendarState)
///
/// Now test the calendar state again.
- /// The thisMonth field should now contain the appointments we just added.
+ /// The this_month field should now contain the appointments we just added.
///
calendar_state = g_action_group_get_action_state (action_group, "calendar");